@@ -1225,6 +1225,24 @@ impl_magnifier_support_colorblind_filters (Magnifier *magnifier)
 #endif
 }
 
+static void
+impl_magnifier_hide_cursor (PortableServer_Servant servant,
+                        CORBA_Environment *ev)
+{
+        Magnifier *magnifier = MAGNIFIER (bonobo_object_from_servant (servant));
+
+	gmag_gs_hide_cursor (magnifier);
+}
+
+static void
+impl_magnifier_show_cursor (PortableServer_Servant servant,
+                            CORBA_Environment *ev)
+{
+	Magnifier *magnifier = MAGNIFIER (bonobo_object_from_servant (servant));
+
+	gmag_gs_show_cursor (magnifier);
+}
+
 static
 CORBA_boolean
 impl_magnifier_full_screen_capable (PortableServer_Servant servant,
@@ -1477,6 +1495,8 @@ magnifier_class_init (MagnifierClass *klass)
 	object_class->dispose = magnifier_gobject_dispose;
 
 	epv->fullScreenCapable = impl_magnifier_full_screen_capable;
+	epv->hideCursor = impl_magnifier_hide_cursor;
+	epv->showCursor = impl_magnifier_show_cursor;
 	epv->supportColorblindFilters =
 		impl_magnifier_support_colorblind_filters;
         epv->_set_SourceDisplay = impl_magnifier_set_source_display;
@@ -1660,7 +1680,8 @@ static void
 magnifier_init_window (Magnifier *magnifier, GdkScreen *screen)
 {
 	GtkWindowType mag_win_type = GTK_WINDOW_TOPLEVEL;
-	if (_is_override_redirect) mag_win_type = GTK_WINDOW_POPUP;
+	if (_is_override_redirect || gmag_gs_use_compositor (magnifier))
+		mag_win_type = GTK_WINDOW_POPUP;
 
 	magnifier->priv->w =
 		g_object_connect (gtk_widget_new (gtk_window_get_type (),
