@@ -60,6 +60,7 @@ typedef struct {
 	GList *zoom_regions;
         gboolean source_initialized;
 	gint crosswire_size;
+	gint crosswire_length;
 	guint32 crosswire_color;
 	gboolean crosswire_clip;
 	gchar *cursor_set;
@@ -165,6 +166,8 @@ void         magnifier_set_cursor_pixmap_by_name (Magnifier *magnifier,
 						  const gchar *cursor_name, 
 						  gboolean source_fallback);
 void         magnifier_transform_cursor (Magnifier *magnifier);
+void         magnifier_zoom_regions_update_pointer (Magnifier *magnifier);
+gboolean     magnifier_full_screen_capable (Magnifier *magnifier);
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
